AllPropsFor

Trait AllPropsFor 

pub trait AllPropsFor<Builder, How> { }
Trait to specify the requirement for Self to be a valid token signaling all props have been provided to the builder.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Token, Builder, How> AllPropsFor<Builder, How> for Token
where Builder: Buildable<Token>, <Builder as Buildable<Token>>::WrappedToken: HasAllProps<<Builder as Buildable<Token>>::Output, How>,